/**
 * Beispielsprogramm zur Demonstration der API oracle.spatial.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import static gdbutil.ConnectionParameters.*;

import java.sql.*;

import oracle.sql.STRUCT;
import oracle.spatial.geometry.JGeometry;
import oracle.spatial.util.ShapefileReaderJGeom;

public class SpatialShapefileExample {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		Class.forName("oracle.jdbc.driver.OracleDriver");
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// SRID bestimmen
		Statement statement = db.createStatement();
		String sql = "SELECT centrum FROM Gemeinden WHERE name = 'Helgoland'";
		ResultSet result = statement.executeQuery(sql);
		int srid = 0;
		if (result.next()) {
			STRUCT struct = (STRUCT) result.getObject("centrum");
			JGeometry jGeom = JGeometry.load(struct);
			srid = jGeom.getSRID();
		}
		result.close();
		statement.close();
		
		// Update vorbereiten
		sql = "UPDATE Gemeinden SET gebiet = ? WHERE name = 'Helgoland'";
		PreparedStatement update = db.prepareStatement(sql);
		// Shapefile ffnen
		//final int DIM = 2;  // Dimension
		ShapefileReaderJGeom reader = new ShapefileReaderJGeom("C:\\Temp\\Helgoland.shp"/*,DIM*/);
		// Alle Geometrien umwandeln und abspeichern
		for (int i=0; i<reader.numRecords(); i++) {
			byte[] data = reader.getGeometryBytes(i/*,DIM*/);
			JGeometry geom = ShapefileReaderJGeom.getGeometry(data,/*DIM,*/srid);
			update.setObject (1,JGeometry.store(geom,db));
			update.executeUpdate();
		}
		// Schlieen
		reader.closeShapefile();
		update.close();
		db.close();
	} // try

	// Fehlerbehandlung:
	catch (Exception ex) {
		System.err.println("SpatialShapefileExample.main: "+ex);
		ex.printStackTrace();
	}
}
}
